@@ -8,8 +8,8 @@ set -o pipefail
 export PYTHONUNBUFFERED=1
 
 function check_kibana {
-    # Query kibana, and check that the returned page looks like a kibana page.
-    KIBANA_URL=${OS_AUTH_URL%:*}:5601
+    # Perform and validate a basic status page check
+    KIBANA_URL=${OS_AUTH_URL%:*}:5601/api/status
     output_path=$1
     kibana_password=$(awk '$1 == "kibana_password:" { print $2 }' /etc/kolla/passwords.yml)
     args=(
@@ -25,7 +25,26 @@ function check_kibana {
     if ! curl "${args[@]}" $KIBANA_URL > $output_path; then
         return 1
     fi
-    if ! grep '<title>Kibana</title>' $output_path >/dev/null; then
+    if ! grep 'Looking good' $output_path >/dev/null; then
+        return 1
+    fi
+}
+
+function check_elasticsearch {
+    # Verify that we see a healthy index created due to Fluentd forwarding logs
+    ELASTICSEARCH_URL=${OS_AUTH_URL%:*}:9200/_cluster/health
+    output_path=$1
+    args=(
+        --include
+        --location
+        --fail
+    )
+    if ! curl "${args[@]}" $ELASTICSEARCH_URL > $output_path; then
+        return 1
+    fi
+    # NOTE(mgoddard): Status may be yellow because no indices have been
+    # created.
+    if ! grep -E '"status":"(green|yellow)"' $output_path >/dev/null; then
         return 1
     fi
 }
@@ -75,7 +94,6 @@ function check_prometheus {
 }
 
 function test_kibana {
-    # TODO(mgoddard): Query elasticsearch for logs.
     echo "TESTING: Kibana"
     output_path=$(mktemp)
     attempt=1
@@ -92,6 +110,23 @@ function test_kibana {
     echo "SUCCESS: Kibana"
 }
 
+function test_elasticsearch {
+    echo "TESTING: Elasticsearch"
+    output_path=$(mktemp)
+    attempt=1
+    while ! check_elasticsearch $output_path; do
+        echo "Elasticsearch not accessible yet"
+        attempt=$((attempt+1))
+        if [[ $attempt -eq 12 ]]; then
+            echo "FAILED: Elasticsearch did not become accessible. Response:"
+            cat $output_path
+            return 1
+        fi
+        sleep 10
+    done
+    echo "SUCCESS: Elasticsearch"
+}
+
 function test_grafana {
     echo "TESTING: Grafana"
     output_path=$(mktemp)
@@ -127,28 +162,11 @@ function test_prometheus {
     echo "SUCCESS: Prometheus"
 }
 
-function migrate_to_elk_6 {
-    RAW_INVENTORY=/etc/kolla/inventory
-
-    tools/kolla-ansible -i ${RAW_INVENTORY} -vvv -t elasticsearch,kibana upgrade
-}
-
 function test_prometheus_efk_logged {
     . /etc/kolla/admin-openrc.sh
 
     test_kibana
-    test_grafana
-    test_prometheus
-
-    migrate_to_elk_6 &> /tmp/logs/ansible/migrate-elk
-
-    test_kibana
-    test_grafana
-    test_prometheus
-
-    migrate_to_elk_6 &> /tmp/logs/ansible/migrate-elk-again
-
-    test_kibana
+    test_elasticsearch
     test_grafana
     test_prometheus
 }
